@@ -1,7 +1,3 @@
-"""
-
-"""
-
 # %%
 """
 Tutorial 2: Two Lens Galaxies
@@ -13,11 +9,11 @@ model, because they add an extra 5-10 parameters to the `NonLinearSearch` and, m
 between the `MassProfile`'s of the two galaxies can be severe.
 
 However, we can still break their analysis down using a pipeline and give ourselves a shot at getting a good lens
-model. Here, we`re going to fit a double lens system, fitting as much about each individual lens galaxy before fitting
+model. Here, we're going to fit a double lens system, fitting as much about each individual lens galaxy before fitting
 them simultaneously.
 
-Up to now, I`ve put a focus on pipelines being general. The pipeline we write in this example is going to be the
-opposite, specific to the image we`re modeling. Fitting multiple lens galaxies is really difficult and writing a
+Up to now, I've put a focus on pipelines being general. The pipeline we write in this example is going to be the
+opposite, specific to the image we're modeling. Fitting multiple lens galaxies is really difficult and writing a
 pipeline that we can generalize to many lenses isn't currently possible with **PyAutoLens**.
 """
 
@@ -30,6 +26,7 @@ workspace_path = str(here())
 #%cd $workspace_path
 print(f"Working Directory has been set to `{workspace_path}`")
 
+from os import path
 import autolens as al
 import autolens.plot as aplt
 
@@ -43,14 +40,13 @@ we'll use new strong lensing data, where:
 """
 
 # %%
-dataset_type = "chapter_3"
 dataset_name = "light_sersic_x2__mass_sie_x2__source_exp"
-dataset_path = f"dataset/howtolens/{dataset_type}/{dataset_name}"
+dataset_path = path.join("dataset", "howtolens", "chapter_3", dataset_name)
 
 imaging = al.Imaging.from_fits(
-    image_path=f"{dataset_path}/image.fits",
-    noise_map_path=f"{dataset_path}/noise_map.fits",
-    psf_path=f"{dataset_path}/psf.fits",
+    image_path=path.join(dataset_path, "image.fits"),
+    noise_map_path=path.join(dataset_path, "noise_map.fits"),
+    psf_path=path.join(dataset_path, "psf.fits"),
     pixel_scales=0.05,
 )
 
@@ -88,8 +84,8 @@ settings = al.SettingsPhaseImaging(settings_masked_imaging=settings_masked_imagi
 """
 __Pipeline Approach__
 
-Looking at the image, there are clearly two blobs of light corresponding to our two lens galaxies. The source`s 
-light is also pretty complex - the arcs don't posses the rotational symmetry we`re used to seeing up to now. 
+Looking at the image, there are clearly two blobs of light corresponding to our two lens galaxies. The source's 
+light is also pretty complex - the arcs don't posses the rotational symmetry we're used to seeing up to now. 
 Multi-galaxy ray-tracing is just a lot more complicated, which means so is modeling it!
 
 So, how can we break the lens modeling up? As follows:
@@ -106,57 +102,26 @@ So, with this in mind, we've written a pipeline composed of 4 phases:
  4) Fit all relevant parameters simultaneously, using priors from phases 1, 2 and 3.
 """
 
-# %%
-"""
-__Pipeline_Setup_And_Tagging__:
-
-For this pipeline the pipeline setup customizes:
-
- - If there is an `ExternalShear` in the mass model or not.
-
-The pipeline setup again `tags` the output path of a pipeline.
-
-The `path_prefix` belows specify the path the pipeline results are written 
-
- `autolens_workspace/howtolens/output/c3_t2_x2_galaxies/pipeline__light_and_source`
-
-The redshift of the lens and source galaxies are also input (see `examples/model/customize/redshift.py`) for a 
-description of what inputting redshifts into **PyAutoLens** does.
-"""
-
-# %%
-setup_light = al.SetupLightParametric()
-setup_mass = al.SetupMassTotal(with_shear=True)
-setup_source = al.SetupSourceParametric()
-
-setup = al.SetupPipeline(
-    path_prefix="howtolens/c3_t2_x2_galaxies",
-    redshift_lens=0.5,
-    redshift_source=1.0,
-    setup_light=setup_light,
-    setup_mass=setup_mass,
-    setup_source=setup_source,
-)
-
 # %%
 """
 __Pipeline Creation__
 
 To create a `Pipeline`, we call a `make_pipeline` function, which is written in its own Python script: 
 
- `tutorial_2_pipeline_x2_lens_galaxies.py`. 
+ `pipelines/tutorial_2_pipeline_x2_lens_galaxies.py`. 
 
 Before we check it out, lets get the pipeline running, by importing the script, running the `make_pipeline` function
 to create the `Pipeline` object and calling that objects `run` function.
 """
 
 # %%
-from autolens_workspace.howtolens.chapter_3_pipelines import (
-    tutorial_2_pipeline_x2_lens_galaxies,
-)
+from pipelines import tutorial_2_pipeline_x2_lens_galaxies
 
 pipeline_x2_galaxies = tutorial_2_pipeline_x2_lens_galaxies.make_pipeline(
-    setup=setup, settings=settings
+    path_prefix=path.join("howtolens", "c3_t2_x2_galaxies"),
+    settings=settings,
+    redshift_lens=0.5,
+    redshift_source=1.0,
 )
 
 # Uncomment to run.
@@ -170,7 +135,7 @@ Once you`ve done that, come back here and we'll wrap up this tutorial.
 
 # %%
 """
-And, we`re done. This pipeline takes a while to run, as is the nature of multi-galaxy modeling. Nevertheless, 
+And, we're done. This pipeline takes a while to run, as is the nature of multi-galaxy modeling. Nevertheless, 
 the techniques we've learnt above can be applied to systems with even more `Galaxy`'s albeit the increases in 
 parameters will slow down the non-linear search. Here are some more Q&A`s
 
