@@ -9,8 +9,8 @@ wealth of different structures that could be present - bulges, disks, bars, star
 there could be more than one source-galaxy!
 
 In this example, we'll explore how far we can get trying to_fit a complex source using a pipeline. Fitting complex
-source`s is an exercise in diminishing returns. Each component we add to our source model brings with it an
-extra 5-7, parameters. If there are 4 components, or multiple `Galaxy`'s we`re quickly entering the somewhat nasty
+source's is an exercise in diminishing returns. Each component we add to our source model brings with it an
+extra 5-7, parameters. If there are 4 components, or multiple `Galaxy`'s we're quickly entering the somewhat nasty
 regime of 30-40+ parameters in our non-linear search. Even with a pipeline, that is a lot of parameters to fit!
 """
 
@@ -23,6 +23,7 @@ workspace_path = str(here())
 #%cd $workspace_path
 print(f"Working Directory has been set to `{workspace_path}`")
 
+from os import path
 import autolens as al
 import autolens.plot as aplt
 
@@ -36,14 +37,13 @@ we'll use new strong lensing data, where:
 """
 
 # %%
-dataset_type = "chapter_3"
 dataset_name = "mass_sie__source_sersic_x4"
-dataset_path = f"dataset/howtolens/{dataset_type}/{dataset_name}"
+dataset_path = path.join("dataset", "howtolens", "chapter_3", dataset_name)
 
 imaging = al.Imaging.from_fits(
-    image_path=f"{dataset_path}/image.fits",
-    noise_map_path=f"{dataset_path}/noise_map.fits",
-    psf_path=f"{dataset_path}/psf.fits",
+    image_path=path.join(dataset_path, "image.fits"),
+    noise_map_path=path.join(dataset_path, "noise_map.fits"),
+    psf_path=path.join(dataset_path, "psf.fits"),
     pixel_scales=0.1,
 )
 
@@ -63,7 +63,7 @@ aplt.Imaging.subplot_imaging(imaging=imaging, mask=mask)
 # %%
 """
 Yep, that`s a pretty complex source. There are clearly more than 4 peaks of light - I wouldn't like to guess how many
-sources of light there truly is! You`ll also notice I omitted the lens `Galaxy`'s light for this system. This is to 
+sources of light there truly is! You'll also notice I omitted the lens `Galaxy`'s light for this system. This is to 
 keep the number of parameters down and the phases running fast, but we wouldn't get such a luxury for a real galaxy.
 """
 
@@ -84,34 +84,6 @@ settings_masked_imaging = al.SettingsMaskedImaging(grid_class=al.Grid, sub_size=
 
 settings = al.SettingsPhaseImaging(settings_masked_imaging=settings_masked_imaging)
 
-# %%
-"""
-__Pipeline_Setup_And_Tagging__:
-
-For this pipeline the pipeline setup customizes:
-
- - If there is an `ExternalShear` in the mass model or not.
- 
-The `path_prefix` belows specify the path the pipeline results are written 
-
- `autolens_workspace/howtolens/output/c3_t3_complex_source/pipeline__light_and_source`
-
-The redshift of the lens and source galaxies are also input (see `examples/model/customize/redshift.py`) for a 
-description of what inputting redshifts into **PyAutoLens** does.
-"""
-
-# %%
-setup_mass = al.SetupMassTotal(with_shear=True)
-setup_source = al.SetupSourceParametric()
-
-setup = al.SetupPipeline(
-    path_prefix="howtolens/c3_t3_complex_source",
-    redshift_lens=0.5,
-    redshift_source=1.0,
-    setup_mass=setup_mass,
-    setup_source=setup_source,
-)
-
 # %%
 """
 __Pipeline Creation__
@@ -129,12 +101,13 @@ The `path_prefix` below specifies the path the pipeline results are written to,
 """
 
 # %%
-from autolens_workspace.howtolens.chapter_3_pipelines import (
-    tutorial_3_pipeline_complex_source,
-)
+from pipelines import tutorial_3_pipeline_complex_source
 
 pipeline_complex_source = tutorial_3_pipeline_complex_source.make_pipeline(
-    setup=setup, settings=settings
+    path_prefix=path.join("howtolens", "c3_t3_complex_source"),
+    settings=settings,
+    redshift_lens=0.5,
+    redshift_source=1.0,
 )
 
 # Uncomment to run.
