@@ -8,7 +8,7 @@ import pytest
 
 class TestAbstractPositionsSolver:
     def test__solver_with_remove_distance_from_mass_profile_centre__remove_pixels_from_initial_grid(
-        self
+        self,
     ):
 
         grid = al.Grid.manual_1d(
@@ -113,10 +113,16 @@ class TestPositionFinder:
             lensing_obj=tracer, source_plane_coordinate=(0.0, 0.0)
         )
 
-        assert coordinates.in_list[0][0] == pytest.approx((1.028125, -0.003125), 1.0e-4)
-        assert coordinates.in_list[0][1] == pytest.approx((0.009375, -0.95312), 1.0e-4)
-        assert coordinates.in_list[0][2] == pytest.approx((0.009375, 0.95312), 1.0e-4)
-        assert coordinates.in_list[0][3] == pytest.approx(
+        assert coordinates.in_grouped_list[0][0] == pytest.approx(
+            (1.028125, -0.003125), 1.0e-4
+        )
+        assert coordinates.in_grouped_list[0][1] == pytest.approx(
+            (0.009375, -0.95312), 1.0e-4
+        )
+        assert coordinates.in_grouped_list[0][2] == pytest.approx(
+            (0.009375, 0.95312), 1.0e-4
+        )
+        assert coordinates.in_grouped_list[0][3] == pytest.approx(
             (-1.028125, -0.003125), 1.0e-4
         )
 
@@ -143,10 +149,16 @@ class TestPositionFinder:
 
         coordinates = solver.solve_from_tracer(tracer=tracer)
 
-        assert coordinates.in_list[0][0] == pytest.approx((1.028125, -0.003125), 1.0e-4)
-        assert coordinates.in_list[0][1] == pytest.approx((0.009375, -0.95312), 1.0e-4)
-        assert coordinates.in_list[0][2] == pytest.approx((0.009375, 0.95312), 1.0e-4)
-        assert coordinates.in_list[0][3] == pytest.approx(
+        assert coordinates.in_grouped_list[0][0] == pytest.approx(
+            (1.028125, -0.003125), 1.0e-4
+        )
+        assert coordinates.in_grouped_list[0][1] == pytest.approx(
+            (0.009375, -0.95312), 1.0e-4
+        )
+        assert coordinates.in_grouped_list[0][2] == pytest.approx(
+            (0.009375, 0.95312), 1.0e-4
+        )
+        assert coordinates.in_grouped_list[0][3] == pytest.approx(
             (-1.028125, -0.003125), 1.0e-4
         )
 
@@ -181,8 +193,8 @@ class TestPositionFinder:
 
         positions = solver.solve_from_tracer(tracer=tracer)
 
-        assert position_manual_0.in_list[0] == positions.in_list[0]
-        assert position_manual_1.in_list[0] == positions.in_list[1]
+        assert position_manual_0.in_grouped_list[0] == positions.in_grouped_list[0]
+        assert position_manual_1.in_grouped_list[0] == positions.in_grouped_list[1]
 
         g2 = al.Galaxy(
             redshift=1.0, light=al.lp.EllipticalLightProfile(centre=(0.0, 0.0))
@@ -198,8 +210,8 @@ class TestPositionFinder:
 
         positions = solver.solve_from_tracer(tracer=tracer)
 
-        assert position_manual_0.in_list[0] == positions.in_list[0]
-        assert position_manual_1.in_list[0] == positions.in_list[1]
+        assert position_manual_0.in_grouped_list[0] == positions.in_grouped_list[0]
+        assert position_manual_1.in_grouped_list[0] == positions.in_grouped_list[1]
 
 
 class TestGridRemoveDuplicates:
